#![deny(unsafe_code)]
#![warn(
    missing_docs,
    missing_debug_implementations,
    clippy::missing_panics_doc
)]

//! # Voidy
//! ## A library to handle HTTP/2 requests asynchronously.

#[doc(hidden)]
pub use error::Result;

#[doc(inline)]
pub use server::Server;

pub mod error;
pub mod http;
mod server;
